@@ -1,17 +1,15 @@
-from typing import List, Dict, Tuple
-
 from tko.game.cluster import Cluster
 from tko.game.quest import Quest
 from tko.game.task import Task
-
+import os
 from tko.util.decoder import Decoder
 from tko.game.game_builder import GameBuilder
 from tko.game.game_validator import GameValidator
+# from typing import override
+from icecream import ic
 
 import yaml # type: ignore
-
 import re
-import os
 
 def load_html_tags(task: str) -> None | str:
     pattern = r"<!--\s*(.*?)\s*-->"
@@ -23,10 +21,11 @@ def load_html_tags(task: str) -> None | str:
 
 class Game:
     def __init__(self):
-        self.ordered_clusters: List[str] = [] # ordered clusters
-        self.clusters: Dict[str, Cluster] = {} 
-        self.quests: Dict[str, Quest] = {}  # quests indexed by quest key
-        self.tasks: Dict[str, Task] = {}  # tasks indexed by task key
+        self.filename: str = ""
+        self.ordered_clusters: list[str] = [] # ordered clusters
+        self.clusters: dict[str, Cluster] = {} 
+        self.quests: dict[str, Quest] = {}  # quests indexed by quest key
+        self.tasks: dict[str, Task] = {}  # tasks indexed by task key
 
         self.token_level_one = "level_one"
         self.token_level_mult = "level_mult"
@@ -34,7 +33,7 @@ class Game:
         self.level_mult: float = 1.5
 
 
-    def parse_xp(self, content):
+    def parse_xp(self, content: str):
         if content.startswith('---'):
             front_matter = content.split('---')[1].strip()
             yaml_data = yaml.safe_load(front_matter)
@@ -57,45 +56,49 @@ class Game:
             obtained += o
         return obtained, total
 
-    def get_skills_resume(self, avaliable_quests: List[Quest]) -> Tuple[Dict[str, int], Dict[str, int]]:
-        total: Dict[str, int] = {}
-        obtained: Dict[str, int] = {}
-        avaliable_keys = [q.key for q in avaliable_quests]
-        for q in self.quests.values():
-            reachable = q.key in avaliable_keys
-            for t in q.get_tasks():
-                for s in t.skills:
-                    if s in total:
-                        total[s] += t.skills[s]
-                        if reachable:
-                            obtained[s] += int(t.skills[s] * t.get_ratio())
-                        else:
-                            obtained[s] += 0
-                    else:
-                        total[s] = t.skills[s]
-                        if reachable:
-                            obtained[s] = int(t.skills[s] * t.get_ratio())
-                        else:
-                            obtained[s] = 0
-                for s in t.qskills:
-                    if s in total:
-                        total[s] += t.qskills[s]
-                        if reachable:
-                            obtained[s] += int(t.qskills[s] * t.get_ratio())
-                        else:
-                            obtained[s] += 0
-                    else:
-                        total[s] = t.qskills[s]
-                        if reachable:
-                            obtained[s] = int(t.qskills[s] * t.get_ratio())
-                        else:
-                            obtained[s] = 0
-        return total, obtained
+    def get_skills_resume(self, avaliable_quests: list[Quest]) -> tuple[dict[str, float], dict[str, float], dict[str, float]]:
+        # obtained, priority, complete
+        priority: dict[str, float] = {}
+        complete: dict[str, float] = {}
+        obtained: dict[str, float] = {}
+        for c in self.clusters.values():
+            for q in c.get_quests():
+                for t in q.get_tasks():
+                    for skill, value in t.skills.items():
+                        gvalue = (value * t.get_xp() * t.get_ratio())
+                        if gvalue < 0.1:
+                            gvalue = 0
+                        obtained[skill] = obtained.get(skill, 0) + gvalue
+                        if not t.is_optional():
+                            priority[skill] = priority.get(skill, 0) + value * t.get_xp()
+                        complete[skill] = complete.get(skill, 0) + value * t.get_xp()
+
+        # remove all keys with value 0
+        # obtained = {k: v for k, v in obtained.items() if v > 0}
+        # priority = {k: v for k, v in priority.items() if v > 0}
+        # complete = {k: v for k, v in complete.items() if v > 0}
+        return obtained, priority, complete
+
+    def sum_xp(self, obtained: dict[str, float], priority: dict[str, float], complete: dict[str, float]) -> tuple[float, float, float]:
+        total_obtained = 0
+        total_priority = 0
+        total_complete = 0
+        for key, value in complete.items():
+            if obtained.get(key, 0) > 0:
+                ic("Warning: skill", key, "has", value, "XP in complete tasks")
+            total_obtained += obtained.get(key, 0)
+            total_priority += priority.get(key, 0)
+            total_complete += value
+        return total_obtained, total_priority, total_complete
+
 
 
     def parse_file_and_folder(self, filename: str, folder: str, language: str):
         self.filename = filename
-        content = Decoder.load(filename)
+        if filename == "" or not os.path.exists(filename):
+            content = ""
+        else:
+            content = Decoder.load(filename)
         self.parse_xp(content)
 
         gb = GameBuilder(filename, folder).build_from(content, language)
@@ -103,13 +106,13 @@ class Game:
         self.clusters = gb.clusters
         self.quests = gb.collect_quests()
         self.tasks = gb.collect_tasks()
-        GameValidator(filename, self.clusters, self.quests, self.tasks).validate()
+        GameValidator(filename, self.clusters).validate()
 
         # for t in self.tasks.values():
         #     t.get_link(os.path.dirname(filename) + "/")
 
     @staticmethod
-    def is_reachable_quest(q: Quest, cache: Dict[str, bool]):
+    def is_reachable_quest(q: Quest, cache: dict[str, bool]):
         if q.key in cache:
             return cache[q.key]
 
@@ -121,7 +124,7 @@ class Game:
 
     # def __get_reachable_quests(self):
     #     # cache needs to be reseted before each call
-    #     cache: Dict[str, bool] = {}
+    #     cache: dict[str, bool] = {}
     #     return [q for q in self.quests.values() if Game.__is_reachable_quest(q, cache)]
 
     def update_reachable_and_available(self):
@@ -131,16 +134,16 @@ class Game:
         for c in self.clusters.values():
             c.set_reachable(False)
 
-        cache: Dict[str, bool] = {}
+        cache: dict[str, bool] = {}
         for c in self.clusters.values():
             for q in c.get_quests():
                 if Game.is_reachable_quest(q, cache):
                     q.set_reachable(True)
                     c.set_reachable(True)
 
-
+    # @override
     def __str__(self):
-        output = []
+        output: list[str] = []
         for c in self.clusters.values():
             output.append("# " + str(c))
             for q in c.get_quests():
