@@ -1,5 +1,4 @@
-from typing import List, Dict, Any
-from tko.util.text import Text
+from typing import Any
 from tko.play.keys import GuiKeys
 
 class Flag:
@@ -7,37 +6,37 @@ class Flag:
         self._name: str = ""
         self._text: str = ""  # description
         self._char: str = ""
-        self._values: List[str] = ["0", "1"]
+        self._values: list[str] = ["0", "1"]
         self._index: int = 0
         self._location: str = ""
         self._bool = True  # many options
 
-    def set_name(self, _name):
+    def set_name(self, _name: str):
         self._name = _name
         return self
 
-    def set_description(self, _text):
+    def set_description(self, _text: str):
         self._text = _text
         return self
 
-    def set_keycode(self, _key):
+    def set_keycode(self, _key: str):
         self._char = _key
         return self
 
-    def set_values(self, _values: List[str]):
+    def set_values(self, _values: list[str]):
         self._values = _values
         return self
 
-    def index(self, _index):
+    def index(self, _index: int):
         self._index = _index
         return self
 
-    def get_values(self):
+    def get_values(self) -> list[str]:
         return self._values
 
     def toggle(self):
         self._index = (self._index + 1) % len(self._values)
-        return self
+        return None
 
     def get_value(self) -> str:
         return self._values[self._index % len(self._values)]
@@ -60,22 +59,25 @@ class Flag:
     def get_index(self) -> int:
         return self._index
     
+    def is_true(self) -> bool:
+        return self.get_value() != "0"
+    
     def __bool__(self) -> bool:
         return self.get_value() == "1"
     
 
 class Flags:
     minimum = Flag().set_name("Mínimo").set_keycode("M").set_values(["0", "1"])    .set_description("Mostra os requisitos para completar a missão")
-    reward = Flag().set_name("Recompensa").set_keycode("R").set_values(["0", "1"]) .set_description("Mostra a experiência obtida nas tarefas     ")
+    #reward = Flag().set_name("Ganho").set_keycode("G").set_values(["0", "1"]) .set_description("Mostra a experiência obtida nas tarefas     ")
     percent = Flag().set_name("Percentual").set_keycode("P").set_values(["1", "0"]).set_description("Mostra todos os valores em porcentagem      ")
-    admin = Flag().set_name("Admin").set_keycode("A").set_values(["0", "1"])       .set_description("Habilitas todas as missões e tarefas        ")
-    skills = Flag().set_name("Skills").set_keycode("S").set_values(["0", "1"]).set_description("Mostra a barra de skills")
-    graph = Flag().set_name("Graph").set_keycode(GuiKeys.graph).set_values(["0", "1", "2"]).set_description("Muda o Gráfico")
-    devel = Flag().set_name("Devel").set_values(["0", "1"])
+    admin = Flag().set_name("Gamer").set_keycode("G").set_values(["1", "0"])       .set_description("Habilitas todas as missões e tarefas        ")
+    skills = Flag().set_name("Trilhas").set_keycode("t").set_values(["0", "1", "2"]).set_description("Mostra a barra de trilhas de habilidades")
+    graph = Flag().set_name("Graph").set_keycode(GuiKeys.graph).set_values(["0", "1"]).set_description("Muda o Gráfico")
+
 
 class FlagsMan:
-    def __init__(self, data: Dict[str, int]):
-        self.flags: Dict[str, Flag] = {}
+    def __init__(self, data: dict[str, int]):
+        self.flags: dict[str, Flag] = {}
 
         for varname, flag in Flags.__dict__.items():
             if isinstance(flag, Flag):
@@ -85,8 +87,8 @@ class FlagsMan:
             if key in self.flags:
                 self.flags[key].index(_index)
 
-    def get_data(self) -> Dict[str, int]:
-        data = {}
+    def get_data(self) -> dict[str, int]:
+        data: dict[str, int] = {}
         for name, flag in self.flags.items():
             if len(flag.get_values()) > 1:
                 data[name] = flag.get_index()
