@@ -1,23 +1,24 @@
-from typing import List
-from .frame import Frame
-from ..util.text import Text, Token
-from .fmt import Fmt
-import curses
+from tko.play.frame import Frame
+from tko.util.text import Text
+from tko.play.fmt import Fmt
 from typing import Callable
 from tko.play.input_manager import InputManager
+from tko.play.keys import GuiKeys
 from tko.util.symbols import symbols
+from tko.settings.settings import Settings
 
 class Floating:
-    def __init__(self, _align=""):
+    def __init__(self, settings: Settings, _align: str = ""):
         self._frame = Frame(0, 0)
-        self._content: List[Text] = []
+        self._content: list[Text] = []
         self._type = "warning"
         self._enable = True
-        self._extra_exit: List[int] = []
-        self._exit_fn = None
-        self._exit_key = None
+        self._extra_exit: list[int] = []
+        self._exit_fn: Callable[[], None] | None = None
+        self._exit_key: None | int = None
         self._centralize = True
         self._floating_align = _align
+        self.settings = settings
 
     def disable(self):
         self._enable = False
@@ -54,11 +55,11 @@ class Floating:
         self._exit_key = ord(key)
         return self
 
-    def set_exit_fn(self, fn):
+    def set_exit_fn(self, fn: Callable[[], None]):
         self._exit_fn = fn
         return self
 
-    def _set_xy(self, dy, dx):
+    def _set_xy(self, dy: int, dx: int):
         valid = "<>^v"
         for c in self._floating_align:
             if c not in valid:
@@ -70,13 +71,13 @@ class Floating:
         if "<" in self._floating_align:
             x = 1
         elif ">" in self._floating_align:
-            x = cols - dx - 3
+            x = cols - dx - 2
 
         y = (lines - dy) // 2
         if "^" in self._floating_align:
             y = 1
         elif "v" in self._floating_align:
-            y = lines - dy - 5
+            y = lines - dy - 2
 
         self._frame.set_pos(y, x)
         return self
@@ -110,7 +111,7 @@ class Floating:
             self._content.append(line)
         return self
     
-    def set_content(self, content: List[str]):
+    def set_content(self, content: list[str]):
         self._content = [Text().add(x) for x in content]
         return self
 
@@ -184,15 +185,16 @@ class FloatingInputData:
         return self
 
 class FloatingInput(Floating):
-    def __init__(self, _align=""):
-        super().__init__(_align)
+    def __init__(self, settings: Settings, _align: str = ""):
+        super().__init__(settings, _align)
         self._index = 0
-        self._options: List[FloatingInputData] = []
+        self._options: list[FloatingInputData] = []
         self._frame.set_border_color("m")
         self._exit_on_action = True
         self.right_dx = 5 # shortcut space
-        self.search_text: List[str] = []
+        self.search_text: list[str] = []
 
+    # @override
     def calc_dy_dx(self):
         dy, dx = super().calc_dy_dx()
         dy += len(self._options) + 2
@@ -205,7 +207,7 @@ class FloatingInput(Floating):
         return self
 
     def match_search(self, index: int):
-        return "".join(self.search_text) in self._options[index].label().get_text().lower()
+        return "".join(self.search_text) in self._options[index].label().get_str().lower()
 
     def next_option(self):
         if not self.match_search(self._index):
@@ -231,8 +233,9 @@ class FloatingInput(Floating):
                 return
             steps -= 1
 
+    # @override
     def write_content(self):
-        options: List[Text] = []
+        options: list[Text] = []
         dx = self._frame.get_dx() - self.right_dx
         for i, option in enumerate(self._options):
             if not self.match_search(i):
@@ -258,7 +261,7 @@ class FloatingInput(Floating):
 
         return self
 
-    def set_options(self, options: List[FloatingInputData]):
+    def set_options(self, options: list[FloatingInputData]):
         self._options = options
         return self
     
@@ -273,29 +276,39 @@ class FloatingInput(Floating):
                 return
         self._index = -1
 
+    # @override
     def get_input(self) -> int:
         self.draw()
         key: int = Fmt.getch()
         key = InputManager.fix_cedilha(Fmt.get_screen(), key)
         
-        if key == curses.KEY_UP:
+        if key == self.settings.app.get_key_up() or key == ord(GuiKeys.up) or key == ord(GuiKeys.up2):
             self.prev_option()
-        elif key == curses.KEY_DOWN:
+        elif key == self.settings.app.get_key_down() or key == ord(GuiKeys.down) or key == ord(GuiKeys.down2):
             self.next_option()
-        elif key == InputManager.esc:
-            self._enable = False
-        elif any([key == x for x in InputManager.backspace_list]) or key == InputManager.delete:
+        elif key == self.settings.app.get_key_left() or key == ord(GuiKeys.left) or key == ord(GuiKeys.left2):
             self.search_text = self.search_text[:-1]
             self.update_index()
-        elif key >= 32 and key < 127:
+        elif 32 <= key < 127:
             self.search_text += chr(key).lower()
             self.update_index()
+        elif any([key == x for x in InputManager.backspace_list]):
+            if len(self.search_text) > 0:
+                self.search_text = self.search_text[:-1]
+            else:
+                self.search_text = []
+            self.update_index()
         elif key == ord('\n'):
             if self._exit_on_action or self._options[self._index].exit_on_action:
                 self._enable = False
             if self._index != -1:
                 self._options[self._index].action()
             return -1
+        elif key == InputManager.esc:
+            self._enable = False
+            if self._exit_fn is not None:
+                self._exit_fn()
+            return -1
         else:
             return key
         return -1
