@@ -1,7 +1,6 @@
-from typing import Dict
 import random
 
-def random_get(dic: dict, str_key: str, mode:str = "static"):
+def random_get(dic: dict[str, str], str_key: str, mode:str = "static"):
     if mode == "static":
         count = sum([ord(c) for c in str_key])
         keys = list(dic.keys())
@@ -10,7 +9,7 @@ def random_get(dic: dict, str_key: str, mode:str = "static"):
         keys = list(dic.keys())
         return dic[random.choice(keys)]
 
-opening: Dict[str, str] = {}
+opening: dict[str, str] = {}
 
 # opening["parrot"] = r"""
 #                            .    
@@ -38,7 +37,7 @@ opening["estuda"] = r"""
   - Se houver testes, isso será calculado automaticamente
 - Abordagem: como foi a última execução da atividade\?
   - Copiar, ChatGpt, Copilot, Aula, Monitoria, Sozinho
-- Autonomia: se refizer a atividade sozinho e SEM CONSULTA, 
+- Autonomia: se refizer a atividade sozinho e SEM CONSULTA,
     quanto dela você se sente confiante para fazer\?
 
 Cobertura: (  fiz nada ) 0 1 ... 9 ✓ (entreguei tudo)
@@ -92,7 +91,7 @@ Autonomia: (não aprendi) x ▁ ▂ ▃ ▅ █ (refaço sozinho)
 # preguiçosos             ⠰⠇  ⠐⡑⠤⢀ 
 # """
 
-intro: Dict[str, str] = {}
+intro: dict[str, str] = {}
 
 intro["elephant"] = r"""
         ⣀⣀                                                                      
@@ -108,23 +107,9 @@ intro["elephant"] = r"""
    ⠸        ⠈⠉⠛⢿⣿⣿⣿⣿⡄     esquerda direita -> muda o teste apresentado          
 """
 
-compilling: Dict[str, str] = {}
+compilling_image: dict[str, str] = {}
 
-# compilling["bloody"] = r"""
-#  ▄████▄   ▒█████   ███▄ ▄███▓ ██▓███   ██▓ ██▓    ▄▄▄       ███▄    █ ▓█████▄  ▒█████  
-# ▒██▀ ▀█  ▒██▒  ██▒▓██▒▀█▀ ██▒▓██░  ██▒▓██▒▓██▒   ▒████▄     ██ ▀█   █ ▒██▀ ██▌▒██▒  ██▒
-# ▒▓█    ▄ ▒██░  ██▒▓██    ▓██░▓██░ ██▓▒▒██▒▒██░   ▒██  ▀█▄  ▓██  ▀█ ██▒░██   █▌▒██░  ██▒
-# ▒▓▓▄ ▄██▒▒██   ██░▒██    ▒██ ▒██▄█▓▒ ▒░██░▒██░   ░██▄▄▄▄██ ▓██▒  ▐▌██▒░▓█▄   ▌▒██   ██░
-# ▒ ▓███▀ ░░ ████▓▒░▒██▒   ░██▒▒██▒ ░  ░░██░░██████▒▓█   ▓██▒▒██░   ▓██░░▒████▓ ░ ████▓▒░
-# ░ ░▒ ▒  ░░ ▒░▒░▒░ ░ ▒░   ░  ░▒▓▒░ ░  ░░▓  ░ ▒░▓  ░▒▒   ▓▒█░░ ▒░   ▒ ▒  ▒▒▓  ▒ ░ ▒░▒░▒░ 
-#   ░  ▒     ░ ▒ ▒░ ░  ░      ░░▒ ░      ▒ ░░ ░ ▒  ░ ▒   ▒▒ ░░ ░░   ░ ▒░ ░ ▒  ▒   ░ ▒ ▒░ 
-# ░        ░ ░ ░ ▒  ░      ░   ░░        ▒ ░  ░ ░    ░   ▒      ░   ░ ░  ░ ░  ░ ░ ░ ░ ▒  
-# ░ ░          ░ ░         ░             ░      ░  ░     ░  ░         ░    ░        ░ ░  
-# ░                                                                      ░               
-# """
-
-
-executing: str = r"""
+executing_image: str = r"""
 ███████╗██╗  ██╗███████╗ ██████╗██╗   ██╗████████╗ █████╗ ███╗   ██╗██████╗  ██████╗ 
 ██╔════╝╚██╗██╔╝██╔════╝██╔════╝██║   ██║╚══██╔══╝██╔══██╗████╗  ██║██╔══██╗██╔═══██╗
 █████╗   ╚███╔╝ █████╗  ██║     ██║   ██║   ██║   ███████║██╔██╗ ██║██║  ██║██║   ██║
@@ -133,7 +118,7 @@ executing: str = r"""
 ╚══════╝╚═╝  ╚═╝╚══════╝ ╚═════╝ ╚═════╝    ╚═╝   ╚═╝  ╚═╝╚═╝  ╚═══╝╚═════╝  ╚═════╝ 
 """
 
-compilling["computer"] = r"""
+compilling_image["computer"] = r"""
  ██████╗ ██████╗ ███╗   ███╗██████╗ ██╗██╗      █████╗ ███╗   ██╗██████╗  ██████╗ 
 ██╔════╝██╔═══██╗████╗ ████║██╔══██╗██║██║     ██╔══██╗████╗  ██║██╔══██╗██╔═══██╗
 ██║     ██║   ██║██╔████╔██║██████╔╝██║██║     ███████║██╔██╗ ██║██║  ██║██║   ██║
@@ -142,10 +127,8 @@ compilling["computer"] = r"""
  ╚═════╝ ╚═════╝ ╚═╝     ╚═╝╚═╝     ╚═╝╚══════╝╚═╝  ╚═╝╚═╝  ╚═══╝╚═════╝  ╚═════╝ 
 """
 
-success: Dict[str, str] = {}
-
-
-success["success"] = r"""
+success_image: dict[str, str] = {}
+success_image["success"] = r"""
 ███████╗██╗   ██╗ ██████╗███████╗███████╗███████╗ ██████╗ 
 ██╔════╝██║   ██║██╔════╝██╔════╝██╔════╝██╔════╝██╔═══██╗
 ███████╗██║   ██║██║     █████╗  ███████╗███████╗██║   ██║
@@ -154,7 +137,7 @@ success["success"] = r"""
 ╚══════╝ ╚═════╝  ╚═════╝╚══════╝╚══════╝╚══════╝ ╚═════╝ 
 """
 
-images: Dict[str, str] = {}
+images: dict[str, str] = {}
 
 images["pink"] = r"""
 Programando assim, você vai dominar o mundo!
@@ -228,9 +211,6 @@ O miserável é um gênio!
             ⢠  ⠈⣶⢄⡀                ⡰⠁⣠⡔⠉ ⡎    ⢸  ⠃
          ⢠⠇⣀⢼   ⢉⡄⠈⠐⠤⣀         ⢀⡀ ⡜⡡⣾⠃  ⠸      ⡧⢄⡈
        ⣀⠤⠚⠉ ⡆   ⠈⡵⢄⡀  ⠙⠂⠄⣀⡀⠤⠊⠉⢀⣀⣠⡴⢿⣟⠞  ⢀⠇      ⡗⠢⢌
-    ⡠⠔⠉  ⢀⡠⡤⠇  ⢀ ⠰⣣⠈⠐⠤⡀ ⡀⠈⠙⢍⠉⣉⠤⠒⠉⣠⣟⢮⠂⡄ ⣼⠁ ⡆    ⢡⣀ 
-⣿⡷⠖⠉  ⡠⠔⣪⣿⠟⣫   ⢸  ⢩⢆  ⠈⠑⢳⠤⠄⠠⠭⠤⠐⠂⢉⣾⢮⠃⢠⠃⢰⡹ ⢰     ⢸⡉⣳
-⠉ ⢀⡠⠒⠉⣠⠾⠋⢁⠔⠹   ⡈⡇  ⢫⣆   ⠘⣆      ⣘⢾⠃⢀⠏⣠⡳⠁ ⣾      ⠈⠉
 """
 
 
@@ -255,14 +235,6 @@ Espero você no próximo nível!
      '._' / \         _/(   `/   )- ---' ;  /__.J   L.__.\ :
       `._;/7(-.......'  /        ) (     |  |            | |
       `._;l _'--------_/        )-'/     :  |___.    _._./ ;
-        | |                 .__ )-'\  __  \  \  I   1   / / 
-        `-'                /   `-\-(-'   \ \  `.|   | ,' /  
-                           \__  `-'    __/  `-. `---'',-'   
-                              )-._.-- (        `-----'      
-                             )(  l\ o ('..-.                
-                       _..--' _'-' '--'.-. |                
-                __,,-'' _,,-''            \ \               
-
 """
 
 images["coiote"] = r"""
@@ -291,11 +263,6 @@ vou aumentar a dificuldade!
    |_( )                `-._/#\_,-'                  :  ) 
  ,-'  ~)           _,--./  (###)__                   :  : 
  (~~~~_)          /       ; `-'   `--,               |  ; 
- (~~~' )         ;       /@@@@@@.    `.              | /  
- `.HH~;        ,-'  ,-   |@@@ @@@@.   `.             .')  
-  `HH `.      ,'   /     |@@@@@ @@@@.  `.           / /(~)
-   HH   \_   ,'  _/`.    |@@@@@ @@@@@;  `.          ; (~~)
-   ~~`.   \_,'  /   ;   .@@@@@ @@@@@@;\_  \___      ; H~\)
 """
 
 images["piupiu"] = r"""
@@ -427,7 +394,7 @@ images["pikachu"] = r"""
 """
 
 images["yoda"] = r"""
-Que a força esteja com você
+Que a força esteja com você                               
  ⢀⣠⣄⣀⣀⣀               ⣀⣤⣴⣶⡾⠿⠿⠿⠿⢷⣶⣦⣤⣀⡀                     
 ⢰⣿⡟⠛⠛⠛⠻⠿⠿⢿⣶⣶⣦⣤⣤⣀⣀⡀⣀⣴⣾⡿⠟⠋⠉        ⠉⠙⠻⢿⣷⣦⣀         ⢀⣀⣀⣀⣀⣀⣀⣀⡀
  ⠻⣿⣦⡀ ⠉⠓⠶⢦⣄⣀⠉⠉⠛⠛⠻⠿⠟⠋⠁   ⣤⡀  ⢠   ⣠    ⠈⠙⠻⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠿⠟⠛⠛⢻⣿
@@ -612,7 +579,7 @@ mas não quero me arrepender da maneira como vivi.
 
 
 images["gollum"] = r"""
-Meu precioso!
+        Meu precioso!         
         ⣀⣠⣴⣶⡿⠟⠋⠁              
      ⢀⣴⣾⣿⣿⣿⠋      ⠈           
    ⢀⣼⡿⠛⠻⣿⣿⠃⢀            ⢀     
@@ -629,3 +596,169 @@ Meu precioso!
        ⠽⢀⣤⡀ ⢠⣤⡈⠉⠁⠠⠤  ⠘⠿⠋⠁     
          ⠉⠛⠿⠶⢾⣭⢤⡾ ⠠⠒          
 """
+
+images["mickey"] = r"""
+             .-'''-.                                      
+            /       \                                     
+            \       /                                     
+     .-'''-.-`.-.-.<  _                                   
+    /      _,-\ O_O-_/ )  Se você pode sonhar, pode fazer!
+    \     / ,  `   . `|                                   
+     '-..-| \-.,__~ ~ /          .,                       
+           \ `-.__/  /          /"/                       
+          / `-.__.-\`-._    ,",' ;                        
+         / /|    ___\-._`-.; /  ./-.                      
+        ( ( |.-"`   `'\ '-( /  //.-'                      
+         \ \/    {}{}  |   /-. /.-'                       
+          \|           /   '..'                           
+           \        , /                                   
+           ( __`;-;'__`)                                  
+           `//'`   `||`                                   
+          _//       ||                                    
+  .-"-._,(__)     .(__).-""-.                             
+ /          \    /           \                            
+ \          /    \           /                            
+  `'-------`      `--------'`                             
+"""
+
+
+images["homer1"] = r"""
+                         (####)                                              
+                        (#######)                                            
+                      (#########)                                            
+Normalmente eu não sou um homem de rezas, mas se você está aí em cima,       
+por favor me salve, Super-Homem!" (Homer Simpson)                            
+                   (#########)                                               
+   __&__          (#########)                                                
+  /     \        (#########)   |\/\/\/|     /\ /\  /\               /\       
+ |       |      (#########)    |      |     | V  \/  \---.    .----/  \----. 
+ |  (o)(o)       (o)(o)(##)    |      |      \_        /       \          /  
+ C   .---_)    ,_C     (##)    | (o)(o)       (o)(o)  <__.   .--\ (o)(o) /__.
+  | |.___|    /___,   (##)     C      _)     _C         /     \     ()     / 
+  |  \__/       \     (#)       | ,___|     /____,   )  \      >   (C_)   <  
+  /_____\        |    |         |   /         \     /----'    /___\____/___\ 
+ /_____/ \       OOOOOO        /____\          ooooo             /|    |\    
+/         \     /      \      /      \        /     \           /        \   
+"""
+
+images["homer2"] = r"""
+    ___     Existem três jeitos de fazer as coisas: o jeito certo, 
+   //_\\_   o jeito errado, e o meu jeito – que é igual ao jeito   
+ ."\\    ". errado, só que mais rápido (Homer Simpson)             
+/          \                                                       
+|           \_                                                     
+|       ,--.-.)                                                    
+ \     /  o \o\                                                    
+ /\/\  \    /_/                                                    
+  (_.   `--'__)                                                    
+   |     .-'  \                                                    
+   |  .-'.     )                                                   
+   | (  _/--.-'                                                    
+   |  `.___.'                                                      
+         (                                                         
+"""
+
+images["mine"] = r"""
+Isso é um bloco de código?   
+      ⢀⡠⢴  ⠠⠤⠤⠤⠤⢤            
+      ⡇ ⢸    ⡖⠂⢠⢸            
+      ⡇ ⢸ ⡶⡾⡍ ⠤⣤⣸            
+      ⡇ ⢸ ⠉⠉⣁⣀⠉⢉⢸            
+   ⢀⡴ ⠧⢤⡼⠤⠦⠤⠭⠭⢤⣼⣼⣀⣠⣀⡤⠒⠲⡋⣷⡄   
+  ⢀⡾⢸  ⢸⡇ ⠐⠳ ⡐⠙⢸⡏⣀⣼⣇⢀⣤⡶⢯ ⠙⣦  
+ ⢀⠎⢸⣊⣀⡀⡽⣇⡀⢀    ⢸⡟⢂ ⠈⠉⡟⣐⢺⣧ ⣹⡆ 
+⢠⠋⠠⠃  ⡼  ⠁⠊    ⢸⣇ ⠑⢄⡾⢠⢻⢏ ⠋⠚⠃ 
+⢸⡴⠁ ⢀⡞⢠        ⢸⠌⠣⡀⡼⠡⡁⡟⠓⡇    
+ ⠁ ⠒⠊ ⢸⢤⣀⣀⣀⣀   ⢸⡆ ⢹⠁⡜⣼⣀⠼     
+      ⠈⣶⠒⠒⠒⢲⠒⠒⠒⢺   ⠉⠉        
+       ⣿   ⠸⣇⣀⣀⡈⡆            
+       ⢻⡇   ⡇  ⢰⠁            
+       ⢸⢁   ⠃ ⢀⠇             
+       ⠈⢸   ⢸⠤⠜              
+        ⡟⣍⣉⣉⣙⡀               
+        ⠷⠤⠤⠤⠜                
+"""
+
+images["hkitty"] = r"""
+           Que código fofo, gamei.           
+                        ⢀⣀⣤⣀⡀   ⡀⢀⣠⣀⡄        
+      ⢀⣵⡶⢶⣶⣦⣄⣠  ⡀     ⢀⣠⣾⣿⢿⡿⣿⣦⣤⣶⡿⠟⠛⠛⢿⣆⠄      
+     ⣀⣿⠋   ⠈⠙⠻⠿⣿⠿⠿⠿⠿⠿⠿⣿⣿⡿⣯⢿⣽⣻⢿⣿⠁    ⠈⣿⣀      
+     ⢺⡟              ⢠⣿⣿⣽⢻⣿⣿⣿⣿⣿⣿⣶⣦⢠⣤⣤⣿⣯      
+     ⣸⣇              ⢸⣿⣷⣻⢿⣿⣿⣿⡿⣯⣟⡿⣿⣿⣿⢿⡿⣿⣷⡀    
+     ⠙⣿⡾⠂            ⠈⢿⣾⣯⣟⣿⣿⣿⣽⣷⣻⣽⣿⣿⣿⣿⣻⣽⣿⠁    
+     ⣰⡿⠁               ⠉⠛⠛⠉⠉⠙⠿⠾⠿⣾⣿⣿⣿⡿⣽⣾⢏⠁    
+    ⢤⣿⠁                         ⠙⢿⣿⣾⣽⡿⣿⣀     
+    ⣾⡇                            ⠉⠉⠉ ⢻⡇     
+⣀⣀⣄⣀⣿⣇⣀⡀                            ⣤⡴⣾⣿⡶⢶⡶⢆ 
+⠚⠉⠉⠙⢻⡏⠉⠉   ⢠⣿⣿⡄              ⢰⣿⣷      ⢸⡇⠂    
+   ⢠⣺⣿⣤⣤   ⠈⠻⠟      ⣀⣤⣤⣄     ⠘⠻⠋    ⠐⢳⣿⠷⡾⠦⠔  
+  ⠘⠋⠙⠹⣷⡀            ⢿⣄⣠⡿           ⣀⣀⣼⣏      
+      ⣸⣿⣿⠏                         ⢈⣿⣿⣿⣎⡀    
+   ⢠⣴⠿⠋⠉⠙⢿⣦⣄⡀                   ⢀⣠⣴⢿⠏  ⠈⠙⠃   
+   ⠈      ⠈⠹⣻⣷⣶⣤⣤⣤⣀⣀⣀⣀⣀⣀⣀⣀⣀⣤⣤⣤⣶⣾⠟⡫⠁          
+        ⡀⢀⣴⡾⠛⣹⣿⣿⣿⣿⣿⠉⠉⠉⠉⠉⠉⢩⣿⣿⣿⣿⣯⠙⠻⣾⣄          
+     ⢀⣨⡾⠟⠟⠻⣷⣴⣿⣿⣿⣟⣿⣿⣧⣀  ⢀⣠⣿⣿⣿⣟⣿⣿⣧⣴⡿⠛⠻⢷⣆⠄      
+     ⢠⢿⡅   ⢸⣿⣿⣿⣟⣾⣿⣻⣿⣿⣿⣿⣿⣿⣿⣿⣯⣿⣟⣿⣿⡇   ⢠⣿       
+     ⠈⣿⡇   ⣾⣿⣿⢿⣾⣿⣽⡿⣯⣿⣟⣿⣿⣻⣿⣾⣟⣷⣿⣟⣿⣷   ⢸⣿⡀      
+      ⠘⢿⣦⣀⣸⣿⣿⡿⣿⣻⣾⣟⣿⣿⣽⣿⣻⣾⡿⣷⣿⣻⣿⣾⢿⣻⣿⣧⣠⣴⡿⠃       
+        ⠘⠉⢿⣿⣿⢿⣟⣿⣽⣿⣻⣾⢿⣾⣿⣷⣿⢿⣽⣿⣳⣿⡿⣿⣿⣿⠍⠁⠁        
+         ⠘⣿⡟⠿⠿⠿⢿⣿⣾⣿⣿⣿⣿⣿⣿⣿⣿⣿⡿⠿⠿⠿⠿⢿⣿⠄          
+         ⠠⣿⡇         ⢠⣿         ⢸⣿⠄          
+          ⠼⣷⡄        ⠐⣿        ⢀⣾⠧           
+           ⠈⠻⢷⣦⣤⣤⣀⣤⣤⣤⣼⣿⣦⣤⣤⣠⣤⣤⣴⡶⠟⠁⠁           
+             ⠈ ⠈⠉⠉⠉⠉⠁   ⠉⠉⠉⠉  ⠁              
+"""
+
+images["pickaxe"] = r"""
+Melhor minerar bitcoin!       
+         ⢰⣶⣶⣶⣶⣶⣶⣶⣶⣶⣶⡆         
+       ⢰⣶⡎⠉⠉⠉⠉⠉⠉⠉⠉⠉⠉⢱⣶⣶⣶⣶⣶⣶⡆  
+       ⠘⠛⢣⣤⣤⣤⣤⣤⣤⣤⣤⡄ ⠈⠛⠛⠛⠛⣿⣿⡇  
+         ⠘⠛⠛⠛⠛⠛⠛⠛⠛⢣⣤⡄    ⣿⣿⡇  
+                ⣀⣀⡸⠿⢇⣀⣀  ⠻⠿⢃⣀⡀
+              ⣀⣀⠿⠿⢇⣀⡸⠿⠿⣀⣀  ⢸⣿⡇
+              ⣿⣿  ⢸⣿⡇  ⣿⣿  ⢸⣿⡇
+            ⣿⣿  ⣿⣿⡇    ⣿⣿  ⢸⣿⡇
+         ⢸⣿⡇  ⣿⣿       ⣿⣿  ⢸⣿⡇
+       ⢰⣶⡎⠉⠱⣶⣶⠉⠉       ⣿⣿  ⢸⣿⡇
+     ⣶⣶⡌⠉⢱⣶⡆⠉⠉         ⠉⠉⣴⣶⡎⠉⠁
+   ⣤⣤⠛⠛⢡⣤⡜⠛⠃             ⠛⠛⠃  
+⢀⣤⣤⠛⠛⣤⣤⡘⠛⠃                    
+⢸⣿⣿⣀⣀⠿⠿⠃                      
+⠸⠿⠿⠿⠿                         
+"""
+
+
+images["feio"] = r"""
+Esse código é tão feio!     
+          ⢀⡠⠤⠖⢒⠂⢤⣀          
+ ⢀⣀     ⢠⠖⠁      ⠢⣥⣢     ⣠⣤ 
+⢀⣟⣿⣦   ⣰⡿⠿⠷⠶⣄  ⢠⠾⠟⠛⠛⢷⡀ ⢀⡼⣿⣇⡇
+⠈⠛⠛⠿⢕⡂⢴⠁   ⢀⠈⠆⠠⣮⣴⢤⡀⣀⣸⣗⣶⡧⠒⠉⠉⠁
+     ⢹  ⠴⣺⣿⣿⠇  ⠛⡿⣽⣿⣽⠿⠛⢻     
+     ⡌  ⠈⠉⢩     ⣸⣒⣄    ⠇    
+     ⡇ ⢀⡴⠖⠉⠛⠓⠲⠶⠾⠿⠿⠿⢏⡳⡀⠄⣾    
+     ⠃ ⠞ ⣀⣀⣀⣀⣀⣀⣀⣤⣤⣶⣿⣇⢧ ⣿    
+     ⡄   ⠈⠫⢽⣽⣉⣹⣁⣧⣿⠟⣱⣿⣾⢀⣿    
+     ⢃      ⠉⠙⠩⠤⠭⣶⣋⡟⢸⢁⣿⠏    
+      ⠱⡀        ⠈⠛⠝⡇⣘⡾⠋     
+       ⠈⠢⣀       ⣠⣴⣷⠋       
+          ⠑⠠⠤⠤⠤⠤⠾⠟⠋⠁        
+"""
+
+images["riso"] = r"""
+      ⢀⣤⠤⠤⠤⠤⠤⠤⠤⠤⠤⠤⢤⣤⣀⣀⡀      
+    ⢀⡼⠋ ⣀⠄⡂⠍⣀⣒⣒⠂ ⠬⠤⠤⠬⠍⠉⠝⠲⣄⡀  
+   ⢀⡾⠁ ⠊⢔⠕⠈⣀⣀⡀⠈⠆   ⡍⠁ ⠁⢂ ⠈⣷  
+  ⣠⣾⠥  ⣠⢠⣞⣿⣿⣿⣉⠳⣄  ⣀⣤⣶⣶⣶⡄  ⣘⢦⡀
+⢀⡞⡍⣠⠞⢋⡛⠶⠤⣤⠴⠚ ⠈⠙⠁  ⢹⡏⠁ ⣀⣠⠤⢤⡕⠱⣷
+⠘⡇⠇⣯⠤⢾⡙⠲⢤⣀⡀⠤ ⢲⡖⣂⣀  ⢙⣶⣄⠈⠉⣸⡄⠠⣠⡿
+ ⠹⣜⡪ ⠈⢷⣦⣬⣏⠉⠛⠲⣮⣧⣁⣀⣀⠶⠞⢁⣀⣨⢶⢿⣧⠉⡼⠁
+  ⠈⢷⡀  ⠳⣌⡟⠻⠷⣶⣧⣀⣀⣹⣉⣉⣿⣉⣉⣇⣼⣾⣿ ⡇ 
+   ⠈⢳⡄  ⠘⠳⣄⡀⡼⠈⠉⠛⡿⠿⠿⡿⠿⣿⢿⣿⣿⡇ ⡇ 
+     ⠙⢦⣕⠠⣒⠌⡙⠓⠶⠤⣤⣧⣀⣸⣇⣴⣧⠾⠾⠋  ⡇ 
+       ⠈⠙⠶⣭⣒⠩⠖⢠⣤⠄     ⠠⠔⠁⡰ ⣧ 
+           ⠉⠛⠲⢤⣀⣀⠉⠉     ⠁ ⣠⠏ 
+               ⠈⠉⠉⠛⠒⠲⠶⠤⠴⠒⠚⠁  
+"""
