@@ -1,13 +1,11 @@
-from typing import Dict, Callable, Optional
+from typing import Callable
 import curses
 import os
 
+FN_VOID = Callable[[], None]
+
 class InputManager:
-    backspace_list = [8, 127, 263, curses.KEY_BACKSPACE]
-    left_list = [260, curses.KEY_LEFT]
-    right_list = [261, curses.KEY_RIGHT]
-    up_list = [259, curses.KEY_UP]
-    down_list = [258, curses.KEY_DOWN]
+    backspace_list: list[int] = [8, 127, 263, curses.KEY_BACKSPACE]
     a = 97
     d = 100
     tab = 9
@@ -20,7 +18,7 @@ class InputManager:
 
     def __init__(self):
         # stores a function than can return another function
-        self.calls: Dict[int, Callable[[], Optional[Callable[[], None]]]] = {}
+        self.calls: dict[int, Callable[[], FN_VOID] | Callable[[], None]] = {}
 
     def add_int(self, _key: int, fn: Callable[[], None]):
         if _key in self.calls.keys():
@@ -48,7 +46,7 @@ class InputManager:
             os.environ.setdefault('ESCDELAY', '25')
 
     @staticmethod
-    def fix_cedilha(scr, value: int) -> int:
+    def fix_cedilha(scr: curses.window, value: int) -> int:
         if value == InputManager.special_double_key:
             value = scr.getch()
             if value == InputManager.cedilha: #ç
