@@ -2,6 +2,7 @@ class GuiActions:
     tab = "↔TAB"
     leave   = "Sair"
     edit = "Editar"
+    move = "Mover"
     principal = "Principal"
     github = "Web   "
     help = "Ajuda"
@@ -16,28 +17,36 @@ class GuiActions:
     time_limit = "Tempo"
     evaluate_tester = "Avaliar "
     execute_tester  = "Rodar"
+    calibrate = "Calibrar"
     all = "Todos"
 
 class GuiKeys:
-    left = "h"
-    right = "l"
-    down = "j"
-    up = "k"
+    left = "A"
+    right = "D"
+    down = "S"
+    up = "W"
+
+    left2 = "H"
+    right2 = "L"
+    down2 = "J"
+    up2 = "K"
+    calibrate = "C"
 
     palette = "c"
     images = "I"
     down_task = "b"
     activate = "\n"
     key_help = "?"
-        
-    set_lang = "L"
-    github_web = "w"
+    
+    # rate = "R"
+    set_lang_drafts = "R"
+    open_url = "u"
     key_quit = "q"
     edit= "e"
     colors = "C"
     borders = "B"
     search = "/"
-    graph = "v"
+    graph = "\t"
     grade_play = "p"
     execute_tester = "r" # Interact in manual input
     diff = "d"
@@ -46,7 +55,6 @@ class GuiKeys:
     quit   = "q"
     lock = "u"
     limite  = "t"
-    expand = "]"
-    collapse = "["
-    mass = "Y"
+    expand = ">"
+    collapse = "<"
     hidden = "E"
\ No newline at end of file
