@@ -1,27 +1,16 @@
-from typing import List, Any, Dict, Tuple, Union, Set
-
-from tko.settings.app_settings import AppSettings
 from tko.settings.repository import Repository
-
-from tko.util.text import Text, Token
-from tko.util.to_asc import SearchAsc, uni_to_asc
+from tko.util.text import Text
+from tko.util.to_asc import SearchAsc
 from tko.play.flags import Flags
-from tko.game.game import Game
 from tko.game.cluster import Cluster
 from tko.game.quest import Quest
 from tko.game.task import Task
 from tko.play.border import Border
-from tko.play.colors import Colors
 from tko.down.drafts import Drafts
-from tko.util.symbols import symbols
 from tko.settings.settings import Settings
 from tko.play.floating_manager import FloatingManager
-from tko.play.floating import Floating
-# from tko.play.grade_message import GradeMessage
 from tko.util.symbols import symbols
 from tko.game.tree_item import TreeItem
-from tko.settings.logger import Logger
-
 
 class TaskAction:
     BAIXAR   = "Baixar  "
@@ -41,15 +30,16 @@ class TaskTree:
         self.fman = fman
         self.style = Border(settings.app)
         self.colors = settings.colors
-        self.items: List[TreeItem] = []
-        self.all_items: Dict[str, TreeItem] = {}
+        self.items: list[TreeItem] = []
+        self.all_items: dict[str, TreeItem] = {}
         self.selected_item: str = ""
-        self.index_begin = 0
-        self.max_title = 0
-        self.search_text = ""
+        self.index_begin: int = 0
+        self.max_title: int = 0
+        self.search_text: str = ""
+        self.expanded: list[str] = []
         self.load_all_items()
         self.load_from_rep()
-        self.update_tree(admin_mode=Flags.admin, first_loop=True)
+        self.update_tree(admin_mode = Flags.admin.is_true())
         self.reload_sentences()
 
     def load_all_items(self):
@@ -61,8 +51,8 @@ class TaskTree:
                     self.all_items[t.key] = t
 
     def load_from_rep(self):
-        # self.new_items: List[str] = [v for v in self.rep.get_new_items()]
-        self.expanded: List[str] = [v for v in self.rep.get_expanded()]
+        # self.new_items: list[str] = [v for v in self.rep.get_new_items()]
+        self.expanded: list[str] = [v for v in self.rep.get_expanded()]
         self.selected_item = self.rep.get_selected()
 
         # tasks = self.rep.get_tasks()
@@ -74,22 +64,22 @@ class TaskTree:
         self.rep.set_expanded(self.expanded)
         # self.rep.set_new_items([x for x in set(self.new_items)])
         self.rep.set_selected(self.selected_item)
-        tasks = {}
+        tasks: dict[str, str] = {}
         for t in self.game.tasks.values():
-            if not t.is_db_empty():
+            if len(t.info.get_filled_kv()) != 0:
                 tasks[t.key] = t.save_to_db()
         self.rep.set_tasks(tasks)
 
-    def update_tree(self, admin_mode: bool, first_loop: bool = False):
-        if not admin_mode:
-            reachable_clusters = [c.key for c in self.game.clusters.values() if c.is_reachable()]
-            reachable_quests = [q.key for q in self.game.quests.values() if q.is_reachable()]
-            old_reachable = reachable_clusters + reachable_quests
+    def update_tree(self, admin_mode: bool):
+        #if not admin_mode:
+            # reachable_clusters = [c.key for c in self.game.clusters.values() if c.is_reachable()]
+            # reachable_quests = [q.key for q in self.game.quests.values() if q.is_reachable()]
+            # old_reachable = reachable_clusters + reachable_quests
 
         self.game.update_reachable_and_available()
             
         if not admin_mode:
-            reachable_clusters = [c.key for c in self.game.clusters.values() if c.is_reachable()]
+            # reachable_clusters = [c.key for c in self.game.clusters.values() if c.is_reachable()]
             reachable_quests = [q.key for q in self.game.quests.values() if q.is_reachable()]
             reachable_keys = reachable_quests + list(self.game.clusters.keys())
             for key in self.expanded:
@@ -105,7 +95,7 @@ class TaskTree:
 
     def __update_max_title(self):
         min_value = 50
-        items = []
+        items: list[int] = []
         for c in self.game.clusters.values():
             if c.key in self.game.clusters.keys():
                 items.append(len(c.title))
@@ -123,7 +113,7 @@ class TaskTree:
             self.max_title = min_value
 
     def __str_task(self, focus_color: str, t: Task, lig_cluster: str, lig_quest: str, quest_reachable: bool) -> Text:
-        down_symbol = Token(" ")
+        # down_symbol = Text.Token(" ")
         in_focus = focus_color != ""
         down_symbol = symbols.task_to_visit
         if t.link_type == Task.Types.STATIC_FILE:
@@ -149,11 +139,12 @@ class TaskTree:
         output.addf(color_lig_task, lig_quest)
         output.add(down_symbol).add(" ")
         output.add(t.get_prog_symbol()).add(" ")
-        output.add(symbols.approach_list[t.approach]).add(" ")
-        output.add(symbols.autonomy_list[t.autonomy])
+        output.add(symbols.flow_list[t.info.flow]).add(" ")
+        output.add(symbols.edge_list[t.info.edge])
+
 
         if in_focus:
-            output.add(self.style.roundL(focus_color))
+            output.add(self.style.round_l(focus_color))
         else:
             output.add(" ")
 
@@ -166,18 +157,30 @@ class TaskTree:
                 output.addf(color + "g", word + " ")
             elif word.startswith(":"):
                 output.addf(color + "y", word + " ")
+            elif word.startswith("*"):
+                output.addf(color + "c", word + " ")
+            elif word.startswith("+"):
+                output.addf(color + "c", word + " ")
             else:
                 output.addf(color, word + " ")
 
         if in_focus:
-            output.add(self.style.roundR(focus_color))
+            output.add(self.style.round_r(focus_color))
         else:
             output.add(" ")
 
-        if Flags.percent:
-            output.ljust(self.max_title + 10, Token(" "))
-            prog = int(t.get_percent())
-            output.addf("y", str(prog).rjust(3, " ") + "%")
+        output.ljust(self.max_title + 10, Text.Token(" "))
+        # if Flags.percent.is_true():
+        prog = round(t.get_percent())
+        output.addf("y", str(prog).rjust(3, " ") + "%")
+        # else:
+        #     color_rate: list[str] = ["", "c", "g", "y", "m", "r"]
+        #     rate = (t.info.neat + t.info.cool) / 2
+        #     for i in range(1, 6):
+        #         if rate >= i:
+        #             output.addf(color_rate[t.info.easy], symbols.star)
+        #         else:
+        #             output.addf(color_rate[t.info.easy], symbols.open_star)
 
         # if Flags.reward:
         #     xp = ""
@@ -195,7 +198,7 @@ class TaskTree:
         color_reachable = "g" if q.is_reachable() else "r"
         if self.app.get_show_hidden() == False and not Flags.admin:
             for quest in self.game.quests.values():
-                if quest.is_reachable() == False:
+                if not quest.is_reachable():
                     if q.key in quest.requires:
                         color_reachable = "y"
                         break
@@ -215,7 +218,7 @@ class TaskTree:
                 #     focus_color = "r"
 
         if in_focus:
-            output.add(self.style.roundL(focus_color))
+            output.add(self.style.round_l(focus_color))
         else:
             output.add(" ")
 
@@ -224,23 +227,26 @@ class TaskTree:
         #     color = "k" + focus_color
 
         title = q.get_full_title()
-        title = title.ljust(self.max_title + 3, ".")
-
-        output.addf(focus_color, title)
-
-        # done = color + self.colors.task_text_done
-        # todo = color + self.colors.task_text_todo
-        # output.add(self.style.build_bar(title, q.get_percent() / 100, len(title), done, todo, round=False))
+        title = title.ljust(self.max_title + 3, Text.Token("."))
+        if focus_color != "":
+            output.addf(focus_color, title)
+        else:
+            output.add(title)
 
         if in_focus:
-            output.add(self.style.roundR(focus_color))
+            output.add(self.style.round_r(focus_color))
         else:
             output.add(" ")
 
-        if Flags.percent:
-            output.add(" ").add(q.get_resume_by_percent())
-        else:
-            output.add(" ").add(q.get_resume_by_tasks())
+        # if Flags.percent:
+        output.add(" ").add(q.get_resume_by_percent())
+        all_tasks_done = True
+        for t in q.get_tasks():
+            if not t.is_complete():
+                all_tasks_done = False
+                break
+        if all_tasks_done:
+            output.add("🌟")
 
         # if Flags.minimum:
         #     output.add(" ").add(q.get_requirement())
@@ -267,41 +273,42 @@ class TaskTree:
         color = ""
         if focus_color != "":
             color = "k" + focus_color
-        title = cluster.title
 
         title = cluster.title.ljust(self.max_title + 5, ".")
         if focus_color != "":
-            output.add(self.style.roundL(focus_color))
+            output.add(self.style.round_l(focus_color))
         else:
             output.add(" ")
 
         output.addf(color, title)
-        # done = color + self.colors.task_text_done
-        # todo = color + self.colors.task_text_todo
-        # output.add(self.style.build_bar(title, cluster.get_percent() / 100, len(title), done, todo, round=False))
 
         if focus_color != "":
-            output.add(self.style.roundR(focus_color))
+            output.add(self.style.round_r(focus_color))
         else:
             output.add(" ")
 
 
-        if Flags.percent:
-            output.add(" ").add(cluster.get_resume_by_percent())
-        else:
-            output.add(" ").add(cluster.get_resume_by_quests())
+        # if Flags.percent:
+        output.add(" ").add(cluster.get_resume_by_percent())
+        # else:
+        #     output.add(" ").add(cluster.get_resume_by_quests())
         # if cluster.key in self.new_items:
         #     output.addf(self.colors.task_new, " [new]")
 
         return output
 
-    def __get_focus_color(self, item: Union[Quest, Cluster]) -> str:
+    def __get_focus_color_cluster(self, item: Cluster) -> str:
         if not item.is_reachable():
             return "R"
         return self.colors.focused_item
+    
+    def __get_focus_color_quest(self, item: Quest) -> str:
+        if not item.is_reachable():
+                return "R"
+        return self.colors.focused_item
 
-    def filter_by_search(self) -> Tuple[Set[str], str | None]:
-        matches: Set[str] = set()
+    def filter_by_search(self) -> tuple[set[str], str | None]:
+        matches: set[str] = set()
         search = SearchAsc(self.search_text)
         first: None | str = None
         for cluster in self.game.clusters.values():
@@ -319,14 +326,14 @@ class TaskTree:
                         matches.add(cluster.key)
                         matches.add(quest.key)
                         matches.add(task.key)
-        return (matches, first)
+        return matches, first
 
     def __try_add(self, filtered: set[str], matcher: SearchAsc, item: TreeItem):
         if self.search_text == "":
             self.items.append(item)
             return True
         if item.key in filtered:
-            pos = matcher.find(item.sentence.get_text())
+            pos = matcher.find(item.sentence.get_str())
             found = pos != -1
             if found:
                 for i in range(pos, pos + len(self.search_text)):
@@ -352,7 +359,7 @@ class TaskTree:
             quests = [q for q in cluster.get_quests() if q.key in self.game.quests.keys() if q.key in filtered]
             if hide:
                 quests = [q for q in quests if q.is_reachable()]
-            focus_color = self.__get_focus_color(cluster) if self.selected_item == cluster.get_key() else ""
+            focus_color = self.__get_focus_color_cluster(cluster) if self.selected_item == cluster.get_key() else ""
             cluster.sentence = self.__str_cluster(len(quests) > 0, focus_color, cluster)
 
             self.__try_add(filtered, matcher, cluster)
@@ -365,7 +372,8 @@ class TaskTree:
                 if hide:
                     tasks = [t for t in tasks if t.is_reachable()]
                 lig = "├" if q != quests[-1] else "╰"
-                focus_color = self.__get_focus_color(q) if self.selected_item == q.get_key() else ""
+                quest_focus_color: str = self.__get_focus_color_quest(q)
+                focus_color = quest_focus_color if self.selected_item == q.get_key() else ""
                 q.sentence = self.__str_quest(len(tasks) > 0, focus_color, q, lig)
 
                 # self.items.append(Entry(q, sentence))
@@ -374,17 +382,17 @@ class TaskTree:
                     for t in tasks:
                         ligc = "│" if q != quests[-1] else " "
                         ligq = "├ " if t != tasks[-1] else "╰ "
-                        focus_color = self.__get_focus_color(q) if self.selected_item == t.get_key() else ""
-                        t.sentence = self.__str_task(focus_color, t, ligc, ligq, q.is_reachable())
+                        focus_color: str = quest_focus_color if self.selected_item == t.get_key() else ""
+                        t.sentence: Text = self.__str_task(focus_color, t, ligc, ligq, q.is_reachable()) # type: ignore
                         self.__try_add(filtered, matcher, t)
-        # verifying if has any selected item
+        # verifying if it has any selected item
         if self.items:
             found = False
             for item in self.items:
                 if item.get_key() == self.selected_item:
                     found = True
                     break
-            if found == False:
+            if not found:
                 self.selected_item = self.items[0].get_key()
                 self.reload_sentences()
 
@@ -409,7 +417,7 @@ class TaskTree:
                 if qkey not in self.expanded:
                     self.expanded.append(qkey)
 
-    def get_selected_index(self) -> int:
+    def  get_selected_index(self) -> int:
         for i, item in enumerate(self.items):
             if item.key == self.selected_item:
                 return i
@@ -421,51 +429,6 @@ class TaskTree:
             return self.items[index]
         raise IndexError("No item selected")
             
-    def mass_mark(self):
-        obj = self.get_selected_throw()
-        if isinstance(obj, Cluster):
-            cluster: Cluster = obj
-            if cluster.key not in self.expanded:
-                self.expanded.append(cluster.key)
-                return
-            full_open = True
-            for q in cluster.get_quests():
-                if q.key in self.game.quests.keys() and q.key not in self.expanded:
-                    self.expanded.append(q.key)
-                    full_open = False
-            if not full_open:
-                return
-
-            value = None
-            for q in obj.get_quests():
-                for t in q.get_tasks():
-                    if value is not None:
-                        self.set_grade(t, value[0], value[1], value[2])
-                    else:
-                        value = (100, 5, 5) if t.get_percent() < 100 else (0, 0, 0)
-                        self.set_grade(t, value[0], value[1], value[2])
-        elif isinstance(obj, Quest):
-            if obj.key not in self.expanded:
-                self.expanded.append(obj.key)
-            else:
-                value = None
-                for t in obj.get_tasks():
-                    if value is not None:
-                        self.set_grade(t, value[0], value[1], value[2])
-                    else:
-                        value = (100, 5, 5) if t.get_percent() < 100 else (0, 0, 0)
-                        self.set_grade(t, value[0], value[1], value[2])
-        elif isinstance(obj, Task):
-            value = (100, 5, 5) if obj.get_percent() < 100 else (0, 0, 0)
-            self.set_grade(obj, value[0], value[1], value[2])
-
-    def set_grade(self, task: Task, coverage: int, autonomy: int, skill: int):
-        obj = task
-        if isinstance(obj, Task):
-            Logger.get_instance().record_self_grade(obj.key, coverage, autonomy, skill)
-            obj.set_coverage(coverage)
-            obj.set_approach(autonomy)
-            obj.set_autonomy(skill)
 
 
     def set_selected_by_index(self, index: int):
@@ -476,6 +439,8 @@ class TaskTree:
         self.selected_item = self.items[index].key
 
     def arrow_right(self):
+        if len(self.items) == 0:
+            return
         index = self.get_selected_index()
         obj = self.items[index]
         if isinstance(obj, Cluster):
@@ -526,6 +491,8 @@ class TaskTree:
         self.set_selected_by_index(index)
 
     def arrow_left(self):
+        if len(self.items) == 0:
+            return
         index = self.get_selected_index()
         obj = self.items[index]
         if isinstance(obj, Quest):
@@ -577,11 +544,11 @@ class TaskTree:
                 return True
         return False
 
-    def toggle(self, obj: Union[Quest, Cluster]):
+    def toggle(self, obj: Quest | Cluster):
             if not self.fold(obj):
                 self.unfold(obj)
 
-    def get_senteces(self, dy):
+    def get_senteces(self, dy: int) -> list[Text]:
         index = self.get_selected_index()
         if len(self.items) < dy:
             self.index_begin = 0
@@ -591,36 +558,40 @@ class TaskTree:
             elif index >= dy + self.index_begin:  # desceu na tela
                 self.index_begin = index - dy + 1
 
-        sentences: List[Text] = []
+        sentences: list[Text] = []
         for i in range(self.index_begin, len(self.items)):
             sentences.append(self.items[i].sentence)
         return sentences
 
     def move_up(self):
+        if len(self.items) == 0:
+            return
         index = self.get_selected_index()
         self.set_selected_by_index(index - 1)
 
     def move_down(self):
+        if len(self.items) == 0:
+            return
         index = self.get_selected_index()
         self.set_selected_by_index(min(len(self.items) - 1, index + 1))
 
     # return a TaskAction
     def get_task_action(self, task: Task) -> tuple[str, str]:
         if task.link_type == Task.Types.VISITABLE_URL:
-            return ("B", TaskAction.VISITAR)
+            return "B", TaskAction.VISITAR
         if task.link_type == Task.Types.STATIC_FILE:
-            return ("G", TaskAction.EXECUTAR)
+            return "G", TaskAction.EXECUTAR
         
         if not self.is_downloaded_for_lang(task):
-            return ("Y", TaskAction.BAIXAR)
-        return ("G", TaskAction.EXECUTAR)
+            return "Y", TaskAction.BAIXAR
+        return "G", TaskAction.EXECUTAR
         
     def is_downloaded_for_lang(self, task: Task):
         folder = task.get_folder()
         lang = self.rep.get_lang()
         if folder is None:
             return False
-        drafts = Drafts.load_drafs(folder, lang)
+        drafts = Drafts.load_drafts_only(folder, lang)
         if drafts:
             return True
         return False
