@@ -1,17 +1,16 @@
 import curses
 import enum
 import os
-from typing import List, Optional, Tuple
+from typing import Callable, Optional
 
 from tko.game.task import Task
 from tko.play.border import Border
-from tko.play.flags import Flags
 from tko.play.floating import Floating, FloatingInput, FloatingInputData
 from tko.play.floating_manager import FloatingManager
 from tko.play.fmt import Fmt
 from tko.play.frame import Frame
-from tko.play.images import compilling, executing, images, intro, random_get, success
-from tko.play.keys import GuiActions, GuiKeys, GuiKeys
+from tko.play.images import compilling_image, executing_image, images, intro, random_get, success_image
+from tko.play.keys import GuiActions, GuiKeys
 from tko.play.opener import Opener
 from tko.run.diff_builder import DiffBuilder
 from tko.run.solver_builder import CompileError
@@ -19,18 +18,19 @@ from tko.run.unit import Unit
 from tko.run.unit_runner import UnitRunner
 from tko.run.wdir import Wdir
 from tko.settings.settings import Settings
-from tko.util.consts import ExecutionResult
+from tko.enums.execution_result import ExecutionResult
 from tko.util.freerun import Free
-from tko.util.text import  Text, Token
+from tko.util.text import  Text
 from tko.util.symbols import symbols
-from tko.util.consts import DiffMode
+from tko.enums.diff_mode import DiffMode
 from tko.play.input_manager import InputManager
-from tko.settings.logger import Logger
-from tko.run.diff_builder_down import DownDiff
-from tko.run.diff_builder_side import SideDiff
+from tko.run.diff_builder_down import DiffBuilderDown
+from tko.run.diff_builder_side import DiffBuilderSide
 from tko.play.tracker import Tracker
 from tko.util.raw_terminal import RawTerminal
 from tko.settings.repository import Repository
+from tko.logger.log_item_exec import LogItemExec
+from tko.logger.log_item_move import LogItemMove
 
 
 class SeqMode(enum.Enum):
@@ -41,7 +41,7 @@ class SeqMode(enum.Enum):
 
 class Tester:
     def __init__(self, settings: Settings, rep: Repository | None, wdir: Wdir, task: Task):
-        self.results: List[Tuple[ExecutionResult, int]] = []
+        self.results: list[tuple[ExecutionResult, int]] = []
         self.wdir = wdir
         self.rep: Repository | None = rep
         self.unit_list = [unit for unit in wdir.get_unit_list()] # unit list to be consumed
@@ -58,13 +58,15 @@ class Tester:
 
         self.locked_index: bool = False
         self.focused_index = 0
-        self.resumes: List[str] = []
+        self.resumes: list[str] = []
 
         self.fman = FloatingManager()
-        self.opener: Optional[Opener] = None
+        self.opener: Opener | None = None
         self.dummy_unit = Unit()
-
-        Logger.get_instance().record_pick(self.task.key)
+        if self.rep:
+            self.rep.logger.store(
+                LogItemMove().set_mode(LogItemMove.Mode.PICK).set_key(self.task.key)
+            )
 
 
     def set_opener(self, opener: Opener):
@@ -81,33 +83,35 @@ class Tester:
         self.exit = True
         return self
 
-    def print_centered_image(self, image: str, color: str, clear=False, align: str = "."):
+    @staticmethod
+    def print_centered_image(image: str, color: str, clear: bool = False, align: str = "."):
         dy, dx = Fmt.get_size()
         lines = image.splitlines()[1:]
         init_y = 4
         if align == "v":
             init_y = dy - len(lines) - 1
         for i, line in enumerate(lines):
-            info = Text().addf(color, line).center(dx - 2, Token(" ", " "))
+            info = Text().addf(color, line).center(dx - 2, Text.Token(" ", " "))
             if clear:
                 Fmt.write(i + init_y, 1, Text().add(" " * info.len()))
             else:
-                Fmt.write(i + init_y, 1, Text().addf(color, line).center(dx - 2, Token(" ", " ")))
+                Fmt.write(i + init_y, 1, Text().addf(color, line).center(dx - 2, Text.Token(" ", " ")))
 
     def show_success(self):
         if self.settings.app.get_use_images():
             out = random_get(images, self.get_folder(), "static")
         else:
-            out = random_get(success, self.get_folder(), "static")
-        self.print_centered_image(out, "g")
+            out = random_get(success_image, self.get_folder(), "static")
+        Tester.print_centered_image(out, "g")
         
-    def show_compilling(self, clear=False):
-        out = random_get(compilling, self.get_folder(), "random")
-        self.print_centered_image(out, "y", clear)
+    def show_compilling(self, clear: bool = False):
+        out = random_get(compilling_image, self.get_folder(), "random")
+        Tester.print_centered_image(out, "y", clear)
 
-    def show_executing(self, clear=False):
-        out = executing
-        self.print_centered_image(out, "y", clear, "v")
+    @staticmethod
+    def show_executing(clear: bool = False):
+        out = executing_image
+        Tester.print_centered_image(out, "y", clear, "v")
 
     def get_folder(self) -> str:
         folder = self.task.get_folder()
@@ -125,38 +129,29 @@ class Tester:
             return unit
         return self.wdir.get_unit(self.focused_index)
 
-    def get_token(self, result: ExecutionResult) -> Token:
+    @staticmethod
+    def get_token(result: ExecutionResult) -> Text.Token:
         if result == ExecutionResult.SUCCESS:
-            return Token(ExecutionResult.get_symbol(ExecutionResult.SUCCESS).text, "G")
+            return Text.Token(ExecutionResult.get_symbol(ExecutionResult.SUCCESS).text, "G")
         elif result == ExecutionResult.WRONG_OUTPUT:
-            return Token(ExecutionResult.get_symbol(ExecutionResult.WRONG_OUTPUT).text, "R")
+            return Text.Token(ExecutionResult.get_symbol(ExecutionResult.WRONG_OUTPUT).text, "R")
         elif result == ExecutionResult.COMPILATION_ERROR:
-            return Token(ExecutionResult.get_symbol(ExecutionResult.UNTESTED).text, "W")
+            return Text.Token(ExecutionResult.get_symbol(ExecutionResult.UNTESTED).text, "W")
         elif result == ExecutionResult.EXECUTION_ERROR:
-            return Token(ExecutionResult.get_symbol(ExecutionResult.EXECUTION_ERROR).text, "Y")
+            return Text.Token(ExecutionResult.get_symbol(ExecutionResult.EXECUTION_ERROR).text, "Y")
         else:
-            return Token(ExecutionResult.get_symbol(ExecutionResult.UNTESTED).text, "W")
+            return Text.Token(ExecutionResult.get_symbol(ExecutionResult.UNTESTED).text, "W")
 
-    def store_test_track(self, result: int):
+    def store_version(self) -> tuple[bool, int]:
         if self.rep is None:
-            return
-        track_folder = self.rep.get_track_task_folder(self.task.key)
+            return False, 0
+        track_folder = self.rep.paths.get_track_task_folder(self.task.key)
         tracker = Tracker()
         tracker.set_folder(track_folder)
-        tracker.set_files(self.wdir.get_solver().path_list)
-        tracker.set_percentage(result)
-        tracker.store()
+        tracker.set_files(self.wdir.get_solver().args_list)
+        has_changes, total_lines = tracker.store()
+        return has_changes, total_lines
 
-    def store_other_track(self, result: str | None = None):
-        if self.rep is None:
-            return
-        track_folder = self.rep.get_track_task_folder(self.task.key)
-        tracker = Tracker()
-        tracker.set_folder(track_folder)
-        tracker.set_files(self.wdir.get_solver().path_list)
-        if result is not None:
-            tracker.set_result(result)
-        tracker.store()
 
     def process_one(self):
 
@@ -165,9 +160,13 @@ class Tester:
 
         solver = self.wdir.get_solver()
 
-        if solver.compile_error:
-            Logger.get_instance().record_compilation_execution_error(self.task.key)
-            self.store_other_track(ExecutionResult.COMPILATION_ERROR.value)
+        if solver.has_compile_error():
+            mode = LogItemExec.Mode.LOCK if self.locked_index else LogItemExec.Mode.FULL
+            changes, total_lines = self.store_version()
+            if self.rep:
+                self.rep.logger.store(
+                    LogItemExec().set_key(self.task.key).set_mode(mode).set_fail(LogItemExec.Fail.COMP).set_size(changes, total_lines)
+                )
 
             self.mode = SeqMode.finished
             while len(self.unit_list) > 0:
@@ -180,6 +179,13 @@ class Tester:
             self.mode = SeqMode.finished
             unit = self.get_focused_unit()
             unit.result = UnitRunner.run_unit(solver, unit, self.settings.app.timeout)
+
+            changes, total_lines = self.store_version()
+            rate = 100 if unit.result == ExecutionResult.SUCCESS else 0
+            if self.rep:
+                self.rep.logger.store(
+                    LogItemExec().set_key(self.task.key).set_mode(LogItemExec.Mode.LOCK).set_rate(rate).set_size(changes, total_lines)
+                )
             return
 
         if self.wdir.has_tests():
@@ -189,13 +195,19 @@ class Tester:
             unit.result = UnitRunner.run_unit(solver, unit, self.settings.app.get_timeout())
             self.results.append((unit.result, index))
             self.focused_index = index
+            if unit.result == ExecutionResult.EXECUTION_ERROR:
+                self.mode = SeqMode.finished
+                while len(self.unit_list) > 0:
+                    index = len(self.results)
+                    self.unit_list = self.unit_list[1:]
+                    self.results.append((ExecutionResult.EXECUTION_ERROR, index))
 
         if len(self.unit_list) == 0:
             self.mode = SeqMode.finished
             self.focused_index = 0
 
-            done_list: List[Tuple[ExecutionResult, int]] = []
-            fail_list: List[Tuple[ExecutionResult, int]] = []
+            done_list: list[tuple[ExecutionResult, int]] = []
+            fail_list: list[tuple[ExecutionResult, int]] = []
             for data in self.results:
                 unit_result, _ = data
                 if unit_result != ExecutionResult.SUCCESS:
@@ -204,12 +216,17 @@ class Tester:
                     done_list.append(data)
             self.results = fail_list + done_list
             percent: int = (100 * len(done_list)) // len(self.results)
-            self.task.coverage = percent
-            Logger.get_instance().record_test_result(self.task.key, percent)
-            self.store_test_track(percent)
+            self.task.info.rate = percent
+            mode = LogItemExec.Mode.LOCK if self.locked_index else LogItemExec.Mode.FULL
+            changes, total_lines = self.store_version()
+            if self.rep:
+                self.rep.save_config()
+                self.rep.logger.store(
+                    LogItemExec().set_key(self.task.key).set_mode(mode).set_rate(percent).set_size(changes, total_lines)
+                )
 
 
-    def build_top_line_header(self, frame_dx):
+    def build_top_line_header(self, frame_dx : int) -> Text:
         activity_color = "C"
         solver_color = "W"
         sources_color = "Y"
@@ -221,7 +238,7 @@ class Tester:
         # building solvers
         solvers = Text()
         if len(self.get_solver_names()) > 1:
-            solvers.add(Text().add(self.borders.roundL("R")).addf("R", f"{GuiActions.tab}").add(self.borders.sharpR("R")))
+            solvers.add(Text().add(self.borders.round_l("R")).addf("R", f"{GuiActions.tab}").add(self.borders.sharp_r("R")))
         for i, solver in enumerate(self.get_solver_names()):
             if len(self.get_solver_names()) > 1:
                 solvers.add(" ")
@@ -243,7 +260,7 @@ class Tester:
         # building sources
         source_names = Text().add(", ").join([Text().addf(sources_color, f"{name[0]}({name[1]})") for name in self.wdir.sources_names()])
         if self.wdir.has_tests():
-            sources = Text().add(self.borders.roundL(sources_color)).add(source_names).add(self.borders.roundR(sources_color))
+            sources = Text().add(self.borders.round_l(sources_color)).add(source_names).add(self.borders.round_r(sources_color))
         else:
             sources = Text().add(self.borders.border("R", "Nenhum teste cadastrado"))
 
@@ -264,7 +281,7 @@ class Tester:
         if len(done_list) > 0 and self.locked_index:
             _, index = done_list[self.focused_index]
             done_list[self.focused_index] = (self.get_focused_unit().result, index)
-        todo_list: List[Tuple[ExecutionResult, int]] = []
+        todo_list: list[tuple[ExecutionResult, int]] = []
         i = len(done_list)
         for _ in self.unit_list:
             if self.locked_index and i == self.focused_index:
@@ -274,7 +291,7 @@ class Tester:
             i += 1
 
         i = 0
-        show_focused_index = not self.wdir.get_solver().compile_error and not self.mode == SeqMode.intro and not self.is_all_right()
+        show_focused_index = not self.wdir.get_solver().has_compile_error() and not self.mode == SeqMode.intro and not self.is_all_right()
         
         output = Text()
         output.add(self.get_fixed_arrow())
@@ -282,15 +299,15 @@ class Tester:
 
         for unit_result, index in done_list + todo_list:
             foco = i == self.focused_index
-            token = self.get_token(unit_result)
-            extrap = self.borders.roundL(token.fmt)
-            extras = self.borders.roundR(token.fmt)
+            token = Tester.get_token(unit_result)
+            extrap = self.borders.round_l(token.fmt)
+            extras = self.borders.round_r(token.fmt)
             if foco and show_focused_index:
                 # token.fmt = token.fmt.lower() + ""
-                extrap = Token("(")
-                extras = Token(")")
-                # extrap = Token(" ") #self.borders.roundL("")
-                # extras = Token(" ") #self.borders.roundR("")
+                extrap = Text.Token("(")
+                extras = Text.Token(")")
+                # extrap = Text.Token(" ") #self.borders.roundL("")
+                # extras = Text.Token(" ") #self.borders.roundR("")
             if self.locked_index and not foco:
                 output.add("  ").addf(token.fmt.lower(), str(index).zfill(2)).addf(token.fmt.lower(), token.text).add(" ")
             else:
@@ -313,7 +330,7 @@ class Tester:
         diff_text = self.get_diff_symbol()
         output.addf("B", f" {GuiKeys.diff} {diff_text} ")
         # if self.settings.app.has_borders():
-        #     output.addf("Mb", symbols.sharpR.text)
+        #     output.addf("Mb", symbols.sharp_r.text)
         # else:
         #     output.addf("B", " ")
         # timer
@@ -324,7 +341,7 @@ class Tester:
         # output.addf("M", f"{timer}l {value}  ")
         color = "R" if self.locked_index else "G"
         if self.settings.app.get_use_borders():
-            output.addf(color + "b", symbols.sharpR.text)
+            output.addf(color + "b", symbols.sharp_r.text)
         else:
             output.addf("B", " ")
 
@@ -332,18 +349,18 @@ class Tester:
         free = symbols.locked_free.text
         locked = symbols.locked_locked.text
         symbol = locked if self.locked_index else free
-        output.addf(color, f" {GuiKeys.lock} {symbol} ").add(self.borders.sharpR(color))
+        output.addf(color, f" {GuiKeys.lock} {symbol} ").add(self.borders.sharp_r(color))
 
         return output
 
-    def draw_top_bar_content(self, frame):
+    def draw_top_bar_content(self, frame : Frame):
         if not self.wdir.has_tests():
             return
         value = self.get_focused_unit()
         info = Text()
-        if self.wdir.get_solver().compile_error:
+        if self.wdir.get_solver().has_compile_error():
             info = self.borders.border("R", "Erro de compilação")
-        elif value is not None and not self.is_all_right() and not self.mode == SeqMode.intro:
+        elif not self.is_all_right() and not self.mode == SeqMode.intro:
             info = value.str(pad = False)
             # if self.locked_index:
             #     info = self.borders.border(focused_unit_color, info.get_text())
@@ -368,29 +385,25 @@ class Tester:
             return symbols.diff_down.text
         return symbols.diff_left.text
 
-    def make_bottom_line(self) -> List[Text]:
-        cmds: List[Text] = []
+    def make_bottom_line(self) -> list[Text]:
+        cmds: list[Text] = []
+
         text = f"{GuiActions.config} [{GuiKeys.palette}]"
+        cmds.append(self.borders.border("C", f"{GuiActions.move} [{GuiKeys.up}{GuiKeys.left}{GuiKeys.down}{GuiKeys.right}]"))
         cmds.append(self.borders.border("C", text))
-
-        color ="Y"
-        limite = f"{GuiActions.time_limit} {self.get_time_limit_symbol()} [{GuiKeys.limite}]"
-        cmds.append(self.borders.border(color, limite))
-
-        # ativar
         cmds.append(self.borders.border("G", f"{GuiActions.evaluate_tester} [{symbols.newline.text}]"))
-        #editar
+        cmds.append(self.borders.border("G", f"{GuiActions.execute_tester} [{GuiKeys.execute_tester}]"))
         if self.opener is not None:
             cmds.append(self.borders.border("Y", f"{GuiActions.edit} [{GuiKeys.edit}]"))
-        # rodar
-        cmds.append(self.borders.border("C", f"{GuiActions.execute_tester} [{GuiKeys.execute_tester}]"))
-            
+        limite = f"{GuiActions.time_limit} {self.get_time_limit_symbol()} [{GuiKeys.limite}]"
+        cmds.append(self.borders.border("Y", limite))
+
         return cmds
 
     def show_bottom_line(self):
         lines, cols = Fmt.get_size()
         out = Text().add(" ").join(self.make_bottom_line())
-        Fmt.write(lines - 1, 0, out.center(cols, Token(" ")))
+        Fmt.write(lines - 1, 0, out.center(cols, Text.Token(" ")))
 
     def is_all_right(self):
         if self.locked_index or len(self.results) == 0:
@@ -420,14 +433,15 @@ class Tester:
         diff_builder = DiffBuilder(cols)
         diff_builder.set_curses()
 
-        if self.wdir.get_solver().compile_error:
-            received = self.wdir.get_solver().error_msg
+        if self.wdir.get_solver().has_compile_error():
+            executable, _ = self.wdir.get_solver().get_executable()
+            received = executable.get_error_msg().get_str()
             line_list = [Text().add(line) for line in received.splitlines()]
         elif self.settings.app.get_diff_mode() == DiffMode.DOWN or not self.wdir.has_tests():
-            ud_diff = DownDiff(cols, unit)
+            ud_diff = DiffBuilderDown(cols, unit)
             line_list = ud_diff.build_diff()
         else:
-            ss_diff = SideDiff(cols, unit)
+            ss_diff = DiffBuilderSide(cols, unit)
             line_list = ss_diff.build_diff()
 
         self.length = max(1, len(line_list))
@@ -447,13 +461,12 @@ class Tester:
     def get_solver_names(self):
         return sorted(self.wdir.solvers_names())
     
-    def main(self, scr):
+    def main(self, scr: curses.window) -> Optional[Callable[[], bool]]:
         InputManager.fix_esc_delay()
         curses.curs_set(0)  # Esconde o cursor
         Fmt.init_colors()  # Inicializa as cores
         Fmt.set_scr(scr)  # Define o scr como global
         while not self.exit:
-
             Fmt.clear()
             if self.mode == SeqMode.running:
                 if self.wdir.get_solver().not_compiled():
@@ -464,7 +477,7 @@ class Tester:
                     try:
                         self.wdir.get_solver().prepare_exec()
                     except CompileError as e:
-                        self.fman.add_input(Floating("v>").error().put_text(e.message))
+                        self.fman.add_input(Floating(self.settings, "v>").error().put_text(e.message))
                         self.mode = SeqMode.finished
                     Fmt.clear()
                     self.draw_top_bar()
@@ -474,7 +487,7 @@ class Tester:
             self.draw_top_bar()
 
             if self.mode == SeqMode.intro:
-                self.print_centered_image(random_get(intro, self.get_folder()), "y")
+                Tester.print_centered_image(random_get(intro, self.get_folder()), "y")
             else:
                 self.draw_main()
             
@@ -495,17 +508,21 @@ class Tester:
             fn_exec = self.process_key(key)
             if fn_exec is not None:
                 return fn_exec
+        return None
 
-    def run_exec_mode(self):
+    def run_exec_mode(self) -> Callable[[], bool]:
         self.mode = SeqMode.running
         if self.wdir.is_autoload():
             self.wdir.autoload()
             self.wdir.get_solver().set_main(self.get_solver_names()[self.task.main_idx])
         self.mode = SeqMode.finished
-        Logger.get_instance().record_freerun(self.task.key)
-        self.store_other_track("Execução Livre")
+        changes, total_lines = self.store_version()
+        if self.rep:
+            self.rep.logger.store(
+                LogItemExec().set_key(self.task.key).set_mode(LogItemExec.Mode.FREE).set_size(changes, total_lines)
+            )
         header = self.build_top_line_header(RawTerminal.get_terminal_size())
-        return lambda: Free.free_run(self.wdir.get_solver(), show_compilling=True, to_clear=True, wait_input=True, header=header)
+        return lambda: Free.free_run(self.wdir.get_solver(), show_compilation=True, to_clear=True, wait_input=True, header=header)
 
     def run_test_mode(self):
         self.mode = SeqMode.running
@@ -530,16 +547,6 @@ class Tester:
             self.results = []
             self.unit_list = [unit for unit in self.wdir.get_unit_list()]
 
-    def send_char_not_found(self, key):
-        if not Flags.devel:
-            return
-        self.fman.add_input(Floating("v>").error()
-                    .put_text("Tecla")
-                    .put_text(f"char {chr(key)}")
-                    .put_text(f"code {key}")
-                    .put_text("não reconhecida")
-                    .put_text("")
-                    )
 
     def go_left(self):
         if self.mode == SeqMode.intro:
@@ -547,9 +554,9 @@ class Tester:
         if self.mode == SeqMode.finished:
             self.mode = SeqMode.select
         if self.locked_index:
-            self.fman.add_input(Floating("v>").warning().put_text("←\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
+            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("←\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
             return
-        if not self.wdir.get_solver().compile_error:
+        if not self.wdir.get_solver().has_compile_error():
             self.focused_index = max(0, self.focused_index - 1)
             self.diff_first_line = 1000
 
@@ -561,9 +568,9 @@ class Tester:
         if self.mode == SeqMode.finished:
             self.mode = SeqMode.select
         if self.locked_index:
-            self.fman.add_input(Floating("v>").warning().put_text("→\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
+            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("→\nAtividade travada\nAperte {} para destravar".format(GuiKeys.lock)))
             return
-        if not self.wdir.get_solver().compile_error:
+        if not self.wdir.get_solver().has_compile_error():
             self.focused_index = min(len(self.wdir.get_unit_list()) - 1, self.focused_index + 1)
             self.diff_first_line = 1000
 
@@ -580,8 +587,8 @@ class Tester:
     def change_main(self):
         if len(self.get_solver_names()) == 1:
             self.fman.add_input(
-                Floating("v>").warning()
-                .put_text("Seu projeto só tem um arquivo de solução")
+                Floating(self.settings, "v>").warning()
+                .put_text("Seu projeto só tem um arquivo de solução.")
                 .put_text("Essa funcionalidade troca qual dos arquivos")
                 .put_text("de solução será o principal.")
             )
@@ -613,8 +620,7 @@ class Tester:
             self.settings.app.set_timeout(valor)
             self.settings.save_settings()
 
-
-    def process_key(self, key):
+    def process_key(self, key: int) -> Optional[Callable[[], bool]]:
         if key == ord('q') or any([key == x for x in InputManager.backspace_list]):
             self.set_exit()
         elif key == InputManager.esc:
@@ -622,13 +628,13 @@ class Tester:
                 self.locked_index = False
             else:
                 self.set_exit()
-        elif any([key == x for x in InputManager.left_list]) or key == ord(GuiKeys.left):
+        elif key == self.settings.app.get_key_left() or key == ord(GuiKeys.left) or key == ord(GuiKeys.left2):
             self.go_left()
-        elif any([key == x for x in InputManager.right_list]) or key == ord(GuiKeys.right):
+        elif key == self.settings.app.get_key_right() or key == ord(GuiKeys.right) or key == ord(GuiKeys.right2):
             self.go_right()
-        elif key == curses.KEY_DOWN or key == ord(GuiKeys.down):
+        elif key == self.settings.app.get_key_down() or key == ord(GuiKeys.down) or key == ord(GuiKeys.down2):
             self.go_down()
-        elif key == curses.KEY_UP or key == ord(GuiKeys.up):
+        elif key == self.settings.app.get_key_up() or key == ord(GuiKeys.up) or key == ord(GuiKeys.up2):
             self.go_up()
         elif key == ord(GuiKeys.toggle_main):
             self.change_main()
@@ -637,26 +643,32 @@ class Tester:
         elif key == ord(GuiKeys.evaluate):
             self.run_test_mode()
         elif key == ord(GuiKeys.lock):
+            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Função de travamento {}".format("ligada" if not self.locked_index else "desligada")))
             self.lock_unit()
         elif key == ord(GuiKeys.edit):
             if self.opener is not None:
                 self.opener.load_folders_and_open()
         elif key == ord(GuiKeys.limite):
             self.change_limit()
+            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Limite de execução alterado para {}".format(self.get_time_limit_symbol())))
             self.settings.save_settings()
         elif key == ord(GuiKeys.diff):
             self.settings.app.toggle_diff()
+            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Modo de Diff alterado para {}".format(self.settings.app.get_diff_mode().value)))
             self.settings.save_settings()
         elif key == ord(GuiKeys.borders):
             self.settings.app.toggle_borders()
+            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Modo de Bordas alterado para {}".format("ligado" if self.settings.app.get_use_borders() else "desligado")))
             self.settings.save_settings()
         elif key == ord(GuiKeys.images):
             self.settings.app.toggle_images()
+            self.fman.add_input(Floating(self.settings, "v>").warning().put_text("Modo de Imagens alterado para {}".format("ligado" if self.settings.app.get_use_images() else "desligado")))
             self.settings.save_settings()
         elif key == ord(GuiKeys.palette):
             self.command_pallete()
         elif key != -1 and key != curses.KEY_RESIZE:
-            self.send_char_not_found(key)
+            self.fman.add_input( Floating(self.settings, "v>").error().put_text(f"Tecla char:{chr(key)}, code:{key}, não reconhecida") )
+        return None
 
     def command_pallete(self):
         options: list[FloatingInputData] = []
@@ -713,7 +725,7 @@ class Tester:
         )
 
         self.fman.add_input(
-            FloatingInput("v").set_text_ljust()
+            FloatingInput(self.settings, "v").set_text_ljust()
                       .set_header(" Selecione uma ação da lista ")
                       .set_options(options)
                       .set_exit_on_enter(False)
@@ -722,20 +734,25 @@ class Tester:
 
     def run(self):
         while True:
-            free_run_fn = curses.wrapper(self.main)
-            if free_run_fn == None:
-                Logger.get_instance().record_back(self.task.key)
+            free_run_fn = curses.wrapper(self.main) # type: ignore
+            if free_run_fn is None:
+                if self.rep:
+                    self.rep.logger.store(
+                            LogItemMove().set_mode(LogItemMove.Mode.BACK).set_key(self.task.key)
+                        )
                 break
             else:
-                while(True):
+                while True:
                     try:
                         repeat = free_run_fn()
-                        if repeat == False:
+                        if not repeat:
                             break
                     except CompileError as e:
                         self.mode = SeqMode.finished
-                        Logger.get_instance().record_compilation_execution_error(self.task.key)
-                        self.store_other_track(ExecutionResult.COMPILATION_ERROR.value)
+                        if self.rep:
+                            self.rep.logger.store(
+                                            LogItemExec().set_key(self.task.key).set_mode(LogItemExec.Mode.FREE).set_fail(LogItemExec.Fail.COMP)
+                                        )
                         print(e)
                         input("Pressione enter para continuar")
                         break
