@@ -1,11 +1,9 @@
-from typing import List
 import os
 
-from ..util.identifier import Identifier
-
-from ..util.pattern import PatternLoader
-from ..util.consts import IdentifierType
-from .unit import Unit
+from tko.util.identifier import Identifier
+from tko.util.pattern_loader import PatternLoader
+from tko.enums.identifier_type import IdentifierType
+from tko.run.unit import Unit
 from tko.util.decoder import Decoder
 
 class Writer:
@@ -17,7 +15,7 @@ class Writer:
     def to_vpl(unit: Unit):
         text = "case=" + unit.case + "\n"
         text += "input=" + unit.inserted
-        text += "output=\"" + unit.expected + "\"\n"
+        text += "output=\"" + unit.get_expected() + "\"\n"
         if unit.grade is None:
             text += "\n"
         else:
@@ -33,8 +31,8 @@ class Writer:
             text += " " + str(unit.grade) + "%"
         text += '\n' + unit.inserted
         text += "======== EXPECT\n"
-        text += unit.expected
-        if unit.expected != '' and unit.expected[-1] != '\n':
+        text += unit.get_expected()
+        if unit.get_expected() != '' and unit.get_expected()[-1] != '\n':
             text += '\n'
         text += "<<<<<<<< FINISH\n\n"
         return text
@@ -45,11 +43,11 @@ class Writer:
         with open(os.path.join(folder, file_source.input_file), "w", encoding="utf-8") as f:
             f.write(unit.inserted)
         with open(os.path.join(folder, file_source.output_file), "w", encoding="utf-8") as f:
-            f.write(unit.expected)
+            f.write(unit.get_expected())
 
     @staticmethod
-    def save_target(target: str, unit_list: List[Unit], quiet: bool) -> bool:
-        def save_dir(_target: str, _unit_list):
+    def save_target(target: str, unit_list: list[Unit], quiet: bool) -> bool:
+        def save_dir(_target: str, _unit_list: list[Unit]):
             folder = _target
             pattern_loader = PatternLoader()
             number = 0
@@ -57,7 +55,7 @@ class Writer:
                 Writer.save_dir_files(folder, pattern_loader, str(number).zfill(2), unit)
                 number += 1
 
-        def save_file(_target, _unit_list):
+        def save_file(_target: str, _unit_list: list[Unit]):
             if _target.endswith(".tio"):
                 _new = "\n".join([Writer.to_tio(unit) for unit in _unit_list])
             else:
